@@ -2,6 +2,17 @@
 from typing import Generator, List, Optional, Union
 
 
+class EmptyResponse(Exception):
+    """Exception raised when the input response is empty."""
+
+    def __init__(self) -> None:
+        self.message = "The input response is empty."
+        super().__init__(self.message)
+
+    def __str__(self) -> str:
+        return self.message
+
+
 class InvalidInputType(Exception):
     """Exception raised when a function argument type is invalid.
 
@@ -69,3 +80,17 @@ class MissingAttribute(Exception):
 
     def __str__(self) -> str:
         return self.message
+
+
+class UndeterminedDims(Exception):
+    """Exception raised for dimensions cannot be determined."""
+
+    def __init__(self) -> None:
+        self.message = (
+            "Dimensions cannot be determined from the dataset,"
+            + "they must be provided via ds_dims argument."
+        )
+        super().__init__(self.message)
+
+    def __str__(self) -> str:
+        return self.message
