@@ -1,101 +1,136 @@
 """Tests for PyGeoUtils"""
 import io
-import shutil
 
-import pytest
-import rasterio
-from pygeoogc import WFS, WMS
+from pygeoogc import WMS, ArcGISRESTful, ServiceURL
 from shapely.geometry import Polygon
 
 import pygeoutils as geoutils
-from pygeoutils import MatchCRS
 
 DEF_CRS = "epsg:4326"
+ALT_CRS = "epsg:4269"
+GEO_URB = Polygon(
+    [
+        [-118.72, 34.118],
+        [-118.31, 34.118],
+        [-118.31, 34.518],
+        [-118.72, 34.518],
+        [-118.72, 34.118],
+    ]
+)
+
+GEO_NAT = Polygon(
+    [[-69.77, 45.07], [-69.31, 45.07], [-69.31, 45.45], [-69.77, 45.45], [-69.77, 45.07]]
+)
+SMALL = 1e-3
 
 
-@pytest.fixture
-def geometry_nat():
-    return Polygon(
-        [[-69.77, 45.07], [-69.31, 45.07], [-69.31, 45.45], [-69.77, 45.45], [-69.77, 45.07]]
+def test_json2geodf():
+    geom = [
+        (-97.06138, 32.837),
+        (-97.06133, 32.836),
+        (-97.06124, 32.834),
+        (-97.06127, 32.832),
+    ]
+
+    service = ArcGISRESTful(ServiceURL().restful.nhdplus_epa, 2, outformat="json", crs=ALT_CRS)
+    service.oids_bygeom(
+        geom, geo_crs=ALT_CRS, sql_clause="FTYPE NOT IN (420,428,566)", distance=1500
     )
+    rjosn = service.get_features(return_m=True)
+    flw = geoutils.json2geodf(rjosn * 2, ALT_CRS, DEF_CRS)
+
+    assert abs(flw.LENGTHKM.sum() - 8.917 * 2) < SMALL
 
 
-@pytest.fixture
-def geometry_urb():
-    return Polygon(
-        [
-            [-118.72, 34.118],
-            [-118.31, 34.118],
-            [-118.31, 34.518],
-            [-118.72, 34.518],
-            [-118.72, 34.118],
-        ]
-    )
-
-
-@pytest.mark.flaky(max_runs=3)
-def test_gtiff2array(geometry_nat):
-    url_wms = "https://www.mrlc.gov/geoserver/mrlc_download/wms"
+def test_gtiff2array():
     wms = WMS(
-        url_wms,
-        layers="NLCD_Land_Cover_Change_Index_Science_product_L48",
+        ServiceURL().wms.mrlc,
+        layers="NLCD_2011_Tree_Canopy_L48",
         outformat="image/geotiff",
         crs=DEF_CRS,
     )
     r_dict = wms.getmap_bybox(
-        geometry_nat.bounds,
+        GEO_NAT.bounds,
         1e3,
         box_crs=DEF_CRS,
     )
-    cover_box = geoutils.gtiff2xarray(r_dict, geometry_nat.bounds, DEF_CRS)
-    cover_msk = geoutils.xarray_geomask(cover_box, geometry_nat, DEF_CRS)
-    cover = geoutils.gtiff2xarray(r_dict, geometry_nat, DEF_CRS)
-
+    canopy_box = geoutils.gtiff2xarray(r_dict, GEO_NAT.bounds, DEF_CRS)
+    canopy = geoutils.gtiff2xarray(r_dict, GEO_NAT, DEF_CRS)
+    expected = 72.223
     assert (
-        abs(cover_msk.mean().values.item() - 2.444) < 1e-3
-        and abs(cover.mean().values.item() - 2.444) < 1e-3
+        abs(canopy_box.mean().values.item() - expected) < SMALL
+        and abs(canopy.mean().values.item() - expected) < SMALL
     )
 
 
-@pytest.mark.flaky(max_runs=3)
-def test_gtiff2file(geometry_nat):
-    url_wms = "https://www.mrlc.gov/geoserver/mrlc_download/wms"
-    wms = WMS(
-        url_wms,
-        layers="NLCD_Land_Cover_Change_Index_Science_product_L48",
-        outformat="image/geotiff",
-        crs=DEF_CRS,
-    )
-    r_dict = wms.getmap_bybox(
-        geometry_nat.bounds,
-        1e3,
-        box_crs=DEF_CRS,
-    )
-    geoutils.gtiff2file(r_dict, geometry_nat, DEF_CRS, "raster")
-    with rasterio.open("raster/NLCD_Land_Cover_Change_Index_Science_product_L48_dd_0_0.gtiff") as f:
-        mean = f.read().mean()
+def test_envelope():
+    resp = """
+    {
+      "attributes": {"OBJECTID": 5141},
+      "geometry": {
+      "xmin" : -109.55, "ymin" : 25.76, "xmax" : -86.39, "ymax" : 49.94,
+      "zmin" : -12.0, "zmax" : 13.3,
+      "spatialReference" : {"wkid" : 4326}}
+    }"""
 
-    shutil.rmtree("raster")
-    assert abs(mean - 2.444) < 1e-3
+    expected = {
+        "type": "Feature",
+        "geometry": {
+            "type": "Polygon",
+            "coordinates": [
+                [
+                    [-86.39, 49.94],
+                    [-109.55, 49.94],
+                    [-109.55, 25.76],
+                    [-86.39, 25.76],
+                    [-86.39, 49.94],
+                ]
+            ],
+        },
+        "properties": {"OBJECTID": 5141},
+        "id": 5141,
+    }
+
+    assert geoutils.arcgis2geojson(resp) == expected
 
 
-@pytest.mark.flaky(max_runs=3)
-def test_json2geodf(geometry_urb):
-    url_wfs = "https://hazards.fema.gov/gis/nfhl/services/public/NFHL/MapServer/WFSServer"
+def test_attr_none():
+    resp = """
+    {
+      "geometry": {
+      "xmin" : -109.55, "ymin" : 25.76, "xmax" : -86.39, "ymax" : 49.94,
+      "zmin" : -12.0, "zmax" : 13.3,
+      "spatialReference" : {"wkid" : 4326}}
+    }"""
+    expected = {
+        "type": "Feature",
+        "geometry": {
+            "type": "Polygon",
+            "coordinates": [
+                [
+                    [-86.39, 49.94],
+                    [-109.55, 49.94],
+                    [-109.55, 25.76],
+                    [-86.39, 25.76],
+                    [-86.39, 49.94],
+                ]
+            ],
+        },
+        "properties": None,
+    }
+    assert geoutils.arcgis2geojson(resp) == expected
 
-    wfs = WFS(
-        url_wfs,
-        layer="public_NFHL:Base_Flood_Elevations",
-        outformat="esrigeojson",
-        crs="epsg:4269",
-        version="2.0.0",
-    )
-    bbox = geometry_urb.bounds
-    r = wfs.getfeature_bybox(bbox, box_crs=DEF_CRS)
-    flood = geoutils.json2geodf([r.json(), r.json()], "epsg:4269", DEF_CRS)
-    flood = flood.drop_duplicates()
 
-    assert abs(flood["ELEV"].sum() - 631366.6) < 1e-1
+def test_geometry_none():
+    resp = '{"attributes": {"OBJECTID": 5141}}'
+    expected = {"type": "Feature", "geometry": None, "properties": {"OBJECTID": 5141}, "id": 5141}
+    assert geoutils.arcgis2geojson(resp) == expected
+
+
+def test_no_id():
+    resp = '{"attributes": {"OBJECTIDs": 5141}}'
+    expected = {"type": "Feature", "geometry": None, "properties": {"OBJECTIDs": 5141}}
+    assert geoutils.arcgis2geojson(resp) == expected
 
 
 def test_ring():
@@ -190,20 +225,6 @@ def test_path():
     assert _path == res
 
 
-def test_matchcrs(geometry_urb):
-    bounds = geometry_urb.bounds
-    crs = "epsg:2149"
-    points = ((bounds[0], bounds[2]), (bounds[1], bounds[3]))
-    geom = MatchCRS.geometry(geometry_urb, DEF_CRS, crs)
-    bbox = MatchCRS.bounds(geometry_urb.bounds, DEF_CRS, crs)
-    coords = MatchCRS.coords(points, DEF_CRS, crs)
-    assert (
-        abs(geom.area - 2475725967.465) < 1e-3
-        and abs(bbox[0] - (-3654030.292)) < 1e-3
-        and abs(coords[0][-1] == (-3588088.81)) < 1e-3
-    )
-
-
 def test_show_versions():
     f = io.StringIO()
     geoutils.show_versions(file=f)
